==> org.opennms.features.telemetry.config.jaxb-23.0.0-20181002.203603-92-sources.jar: org/opennms/netmgt/telemetry/config/dao/TelemetrydConfigDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.config.dao;

import org.opennms.core.xml.AbstractJaxbConfigDao;
import org.opennms.netmgt.telemetry.config.model.TelemetrydConfiguration;

public class TelemetrydConfigDao extends AbstractJaxbConfigDao<TelemetrydConfiguration, TelemetrydConfiguration> {

    public TelemetrydConfigDao() {
        super(TelemetrydConfiguration.class, "Telemetryd configuration");
    }

    @Override
    protected TelemetrydConfiguration translateConfig(TelemetrydConfiguration config) {
        return config;
    }
}

==> org.opennms.features.telemetry.config.jaxb-27.0.0-20200401.064817-8-sources.jar: org/opennms/netmgt/telemetry/config/dao/TelemetrydConfigDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.config.dao;

import org.opennms.core.xml.AbstractJaxbConfigDao;
import org.opennms.netmgt.telemetry.config.model.TelemetrydConfig;

public class TelemetrydConfigDao extends AbstractJaxbConfigDao<TelemetrydConfig, TelemetrydConfig> {

    public TelemetrydConfigDao() {
        super(TelemetrydConfig.class, "Telemetryd configuration");
    }

    @Override
    protected TelemetrydConfig translateConfig(TelemetrydConfig config) {
        return config;
    }
}
